@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::Util::Test::KENTNL::dztest;
 
-our $VERSION = '1.002000';
+our $VERSION = '1.003000';
 
 # ABSTRACT: Shared dist testing logic for easy dzil things
 
@@ -17,6 +17,8 @@ use Test::DZil qw( Builder );
 use Test::Fatal qw( exception );
 use Test::More qw( );
 use Path::Tiny qw(path);
+use Dist::Zilla::Util;
+use Module::Runtime qw();
 
 ## no critic (ValuesAndExpressions::ProhibitConstantPragma,ErrorHandling::RequireCheckingReturnValueOfEval,Subroutines::ProhibitSubroutinePrototypes)
 use constant CAN_DPATH    => eval { require Data::DPath;       1 };
@@ -259,6 +261,50 @@ sub test_has_built_file {
   return;
 }
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+sub create_plugin {
+  my $nargs = ( my ( $self, $package, $name, $args ) = @_ );
+  if ( 2 == $nargs ) {
+    $name = $package;
+    $args = {};
+  }
+  if ( 3 == $nargs ) {
+    if ( ref $name ) {
+      $args = $name;
+      $name = $package;
+    }
+    else {
+      $args = {};
+    }
+  }
+  my $expanded = Dist::Zilla::Util->expand_config_package_name($package);
+  Module::Runtime::require_module($expanded);
+  return $expanded->new(
+    zilla       => $self->configure,
+    plugin_name => $name,
+    %{$args},
+  );
+}
+
 has tb => (
   is      => ro =>,
   lazy    => 1,
@@ -479,7 +525,7 @@ Dist::Zilla::Util::Test::KENTNL::dztest - Shared dist testing logic for easy dzi
 
 =head1 VERSION
 
-version 1.002000
+version 1.003000
 
 =head1 SYNOPSIS
 
@@ -586,6 +632,24 @@ Also returns it if it exists.
 
   my $object = test->test_has_built_file('dist.ini'); # ok/fail + return
 
+=head2 C<create_plugin>
+
+Create an instance of the named plugin and return it.
+
+  my $t = dztest();
+  $t->add_file('dist.ini', simple_ini( ... ));
+  my $plugin = $t->create_plugin('GatherDir' => { ignore_dotfiles => 1 });
+  # poke at $plugin here
+
+Note: This lets you test plugins outside the requirement of inter-operating
+with C<dzil> phases, but has the downside of not interacting with C<dzil> phases,
+or even being I<*seen*> by C<dzil> phases.
+
+But this is OK if you want to directly test a modules interface instead of doing
+it through the proxy of C<dzil>
+
+You can also subsequently create many such objects without requiring a C<dzil build> penalty.
+
 =head2 C<source_file>
 
 Re-fetch content added with C<add_file>.
